Learn R Programming

nhm (version 0.1.2)

ematrix.nhm: Compute the misclassification probability matrix from a fitted nhm model

Description

Outputs the matrix of misclasification probabilities in a misclassification type hidden Markov multi-state model fitted using nhm.

Usage

ematrix.nhm(object, covvalue=NULL)

Value

Returns a list containing a matrix of misclassification probabilities and a matrix of corresponding standard errors computed using the delta method.

Arguments

object

Fitted model object produced using nhm.

covvalue

Optional vector of covariate vectors (should be given in the order specified in the covariate option in nhm). If omitted the function will use the mean values of the covariates.

Author

Andrew Titman a.titman@lancaster.ac.uk

Details

The emat_nhm function used to fit the model is called to obtain the values of the misclassification probabilities at the supplied times for the supplied covariate value.

See Also

nhm, plot.nhm, predict.nhm, qmatrix.nhm