Outputs the matrix of misclasification probabilities in a misclassification type hidden Markov multi-state model fitted using nhm.
ematrix.nhm(object, covvalue=NULL)Returns a list containing a matrix of misclassification probabilities and a matrix of corresponding standard errors computed using the delta method.
Fitted model object produced using nhm.
Optional vector of covariate vectors (should be given in the order specified in the covariate option in nhm). If omitted the function will use the mean values of the covariates.
Andrew Titman a.titman@lancaster.ac.uk
The emat_nhm function used to fit the model is called to obtain the values of the misclassification probabilities at the supplied times for the supplied covariate value.
nhm, plot.nhm, predict.nhm, qmatrix.nhm